aboutsummaryrefslogtreecommitdiffstats
path: root/packages/meshbay-hub/src/meshbay_hub/static/platform.js
diff options
context:
space:
mode:
Diffstat (limited to 'packages/meshbay-hub/src/meshbay_hub/static/platform.js')
-rw-r--r--packages/meshbay-hub/src/meshbay_hub/static/platform.js3
1 files changed, 2 insertions, 1 deletions
diff --git a/packages/meshbay-hub/src/meshbay_hub/static/platform.js b/packages/meshbay-hub/src/meshbay_hub/static/platform.js
index 4b507dc..2cfa673 100644
--- a/packages/meshbay-hub/src/meshbay_hub/static/platform.js
+++ b/packages/meshbay-hub/src/meshbay_hub/static/platform.js
@@ -267,7 +267,7 @@ export const phoneSync = {
};
/**
* Backing up one kind of this phone's data (contacts, messages) to the destination
* every kind shares (docs/MESHBAY_DESIGN.md §9.13). Android only, like
* `photoSync`. See phone-sync.js.
*/
@@ -292,6 +292,7 @@ function docSync(name) {
}
export const contactSync = docSync('contactSync');
+export const calendarSync = docSync('calendarSync');
/** Absent from the Play build, whose policy keeps text messages from it. */
export const messageSync = docSync('messageSync');
@@ -267,7 +267,7 @@ export const phoneSync = {
};
/**
- * Backing up one kind of this phone's data (contacts, messages) to the destination
+ * Backing up one kind of this phone's data (contacts, calendar, messages) to the destination
* every kind shares (docs/MESHBAY_DESIGN.md §9.13). Android only, like
* `photoSync`. See phone-sync.js.